/**
* This file is part of ArmarX.
*
* ArmarX is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* ArmarX is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @package    RobotCOMPONENTS::DMPComponent
* @author     You
* @date       2015 Humanoids Group, H2T, KIT
* @license    http://www.gnu.org/licenses/gpl-2.0.txt
*             GNU General Public License
*/

#ifndef _ROBOTCOMPONENTS_COMPONENT_DMPComponent_SLICE_
#define _ROBOTCOMPONENTS_COMPONENT_DMPComponent_SLICE_

#include <ArmarXCore/interface/core/UserException.ice>
#include <ArmarXCore/interface/core/BasicTypes.ice>

//#include <MemoryX/interface/memorytypes/MemoryEntities.ice>



module armarx
{
    struct cState{
        double pos;
        double vel;
        double acc;
    };

    sequence<double> DVector;

    sequence<cState> cStateVec;

    ["cpp:virtual"]
    class DMPComponentBase
    {
        bool is3rdOrder = false;

        void using3rdOrderDMP();
        void usingBasicDMP();
        void setDMPState(cStateVec state) throws InvalidArgumentException;
        void setParameter(int paraId, double value) throws InvalidArgumentException;
        void setGoal(DVector value) throws InvalidArgumentException;
        void setStartPosition(DVector value) throws InvalidArgumentException;
        void setTimeStamps(DVector value) throws InvalidArgumentException;
        void setCanonicalValues(DVector value) throws InvalidArgumentException;
        void getDMPFromDatabase(string filename) throws InvalidArgumentException;
        cStateVec getNextState() throws InvalidArgumentException;
        void instantiateDMP(int dmptype) throws InvalidArgumentException;
        void trainDMP() throws InvalidArgumentException;
        void storeDMPInDatabase(string cname) throws InvalidArgumentException;
        void readTrajectoryFromFile(string file);
        void removeDMPFromDatabase(string dmpname);

    };

  
};

#endif
